@@ -43,7 +43,9 @@
 #include <QUrl>
 #include <QTextStream>
 #include "kdebugsettings_debug.h"
-
+namespace {
+constexpr char KDebugSettingsDialogGroupName[] = "KDebugSettingsDialog";
+}
 KDebugSettingsDialog::KDebugSettingsDialog(QWidget *parent)
     : QDialog(parent)
 {
@@ -104,7 +106,7 @@ KDebugSettingsDialog::~KDebugSettingsDialog()
 
 void KDebugSettingsDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "KDebugSettingsDialog");
+    KConfigGroup group(KSharedConfig::openConfig(), QLatin1String(KDebugSettingsDialogGroupName));
     const QSize size = group.readEntry("Size", QSize(600, 400));
     if (size.isValid()) {
         resize(size);
@@ -113,7 +115,7 @@ void KDebugSettingsDialog::readConfig()
 
 void KDebugSettingsDialog::saveConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "KDebugSettingsDialog");
+    KConfigGroup group(KSharedConfig::openConfig(), QLatin1String(KDebugSettingsDialogGroupName));
     group.writeEntry("Size", size());
     group.sync();
 }
@@ -132,7 +134,7 @@ void KDebugSettingsDialog::readQtLoggingFile()
 void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
 {
     // KDE debug categories area
-    const QString confAreasFile = QStandardPaths::locate(QStandardPaths::ConfigLocation, QStringLiteral("kde.categories"));
+    const QString confAreasFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("qlogging-categories5/kde.categories"));
     if (confAreasFile.isEmpty()) {
         qCWarning(KDEBUGSETTINGS_LOG) << "Impossible to find kde.categories file";
     } else {
@@ -141,7 +143,8 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
 
     mRenameCategoriesList.clear();
     // Load *.renamecategories file in QStandardPaths::ConfigLocation for kde apps.
-    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::ConfigLocation, QString(), QStandardPaths::LocateDirectory);
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::ConfigLocation, QString(), QStandardPaths::LocateDirectory) +
+            QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("qlogging-categories5/"), QStandardPaths::LocateDirectory);
     for (const QString &dir : dirs) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.renamecategories"));
         for (const QString &file : fileNames) {
@@ -150,6 +153,7 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
     }
     //TODO add load rename file from external kde apps.
     const QStringList dirs2 = QStandardPaths::locateAll(QStandardPaths::GenericConfigLocation, QStringLiteral("qdebug.categories/"), QStandardPaths::LocateDirectory);
+    //qDebug() << " dirs 2 " << dirs2;
     for (const QString &dir : dirs2) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.renamecategories"));
         for (const QString &file : fileNames) {
@@ -158,8 +162,7 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
     }
 
     // Load *.categories file in QStandardPaths::ConfigLocation for kde apps.
-    const QStringList dirs3 = QStandardPaths::locateAll(QStandardPaths::ConfigLocation, QString(), QStandardPaths::LocateDirectory);
-    for (const QString &dir : dirs3) {
+    for (const QString &dir : dirs) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.categories"));
         for (const QString &file : fileNames) {
             if (file != QStringLiteral("kde.categories")) {
@@ -169,8 +172,7 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
     }
 
     // Load *.categories files. in qdebug.categories for external kde apps.
-    const QStringList dirs4 = QStandardPaths::locateAll(QStandardPaths::GenericConfigLocation, QStringLiteral("qdebug.categories/"), QStandardPaths::LocateDirectory);
-    for (const QString &dir : dirs4) {
+    for (const QString &dir : dirs2) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.categories"));
         for (const QString &file : fileNames) {
             KDebugSettingsUtil::readLoggingCategories(dir + QLatin1Char('/') + file, mCategoriesList, true);
